#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Apr 12 16:02:17 2018

@author: mariaclavero
"""


import numpy as np
import math 

#============
# Goda Method
#============

def Goda(theta1,Hc,h,Hsp,tanfondo,L1,d,hp,gammaw,Fc):
    
    # Goda Method coefficients
    
    if theta1>15*np.pi/180:
        beta=theta1-15*np.pi/180
    else:
        beta=0

    eta=0.75*(1+math.cos(beta))*Hc
    hb=h+5*Hsp*tanfondo
    alpha1=0.6+0.5*((4*np.pi*h/L1)/math.sinh(4*np.pi*h/L1))**2
    alpha2=min((((hb-d)/3/hb)*(Hc/d)**2),2*d/Hc)
    alpha3=1-(hp/h)*(1-1/math.cosh(2*np.pi*h/L1))


    # Goda method pressures
    p1=0.5*(1+math.cos(beta))*(alpha1+alpha2*(math.cos(beta))**2)*gammaw*Hc
    p3=alpha3*p1

    if eta>Fc:
        p4=(1-Fc/eta)*p1
    else:
        p4=0

    pu=0.5*(1+math.cos(beta))*alpha1*alpha3*gammaw*Hc

    return p1,p3,p4,pu 

#==================
# Takahashi Method
#==================

def Takahashi(theta1,Hc,h,L1,Hsp,tanfondo,d,hp,Fc,Bm,gammaw,k1):



    hb=h+5*Hsp*tanfondo 

    # Takahashi Method Coefficients
    if theta1>15*np.pi/180:
         beta=theta1-15*np.pi/180
    else:
        beta=0
     
    lambda1=1
    lambda2=1
    lambda3=1
    eta=0.75*(1+math.cos(beta))*Hc*lambda1

# Coefficients
    alpha1=0.6+0.5*((4*np.pi*h/L1)/math.sinh(4*np.pi*h/L1))**2
    alpha2_coef1=((hb-d)/(3*hb))*((Hc/d)**2)
    alpha2_coef2=2*d/Hc
    alpha2=min(alpha2_coef1,alpha2_coef2)
    alpha3=1-hp*(1-1/(math.cosh(2*np.pi*h/L1)))/h
    hc_asterisco=min(eta,Fc)
    alpha4=1-hc_asterisco/eta
    
    delta11=0.93*(Bm/L1-0.12)+0.36*((h-d)/h-0.6)
    delta22=-0.36*(Bm/L1-0.12)+0.93*((h-d)/h-0.6)
        
    if delta11<=0:
        delta1=20*delta11
    else:
        delta1=15*delta11


    if delta22<=0:
        delta2=4.9*delta22
    else:
        delta2=3*delta22


    if Hc<=2*d:
        alpha_I0=Hc/d
    else:
        alpha_I0=2


    if delta2<=0:
        alpha_I1=math.cos(delta2)/math.cosh(delta1)
    else:
        alpha_I1=1/(math.cosh(delta1)*math.sqrt(math.cosh(delta2)))

    alphaI=alpha_I0*alpha_I1
    alpha_asterisco=max(alpha2,alphaI)

# Pressures
    
    p1=0.5*(1+math.cos(beta))*(alpha1*lambda1+alpha_asterisco*lambda2*(math.cos(beta))**2)*gammaw*Hc
    p2=p1/(math.cosh(k1*h))
    p3=alpha3*p1
    p4=alpha4*p1
    pu=0.5*(1+math.cos(beta))*alpha1*alpha3*lambda3*gammaw*Hc


    return  p1,p2,p3,p4,pu